import Icon  from '../Icon.js';
import { z } from 'zod';


const ExerciseResultsFile = z.object({
                                         success: z.boolean().optional(),

                                         containerExitCode: z.number().optional(),

                                         successfulTests: z.number().optional(),
                                         failedTests    : z.number().optional(),

                                         successfulTestsList: z.array(z.string()).optional(),
                                         failedTestsList    : z.array(z.string()).optional(),

                                         otherInformations: z.array(z.object({
                                                                                 name               : z.string(),
                                                                                 description        : z.string().optional(),
                                                                                 icon               : z.enum(Object.keys(Icon) as [ firstKey: string, ...otherKeys: Array<string> ]).optional(),
                                                                                 itemsOrInformations: z.union([ z.array(z.string()), z.string() ])
                                                                             }))
                                             .optional()
                                     }).strict().transform(value => {
    if ( value.successfulTests === undefined && value.successfulTestsList !== undefined ) {
        value.successfulTests = value.successfulTestsList.length;
    }

    if ( value.failedTests === undefined && value.failedTestsList !== undefined ) {
        value.failedTests = value.failedTestsList.length;
    }

    return value;
});


type ExerciseResultsFile = z.infer<typeof ExerciseResultsFile>;


export default ExerciseResultsFile;